==> field3d_1.6.1.orig.tar.gz: Field3D-1.6.1/src/InitIO.cpp <==
//----------------------------------------------------------------------------//

/*
 * Copyright (c) 2009 Sony Pictures Imageworks Inc
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the
 * distribution.  Neither the name of Sony Pictures Imageworks nor the
 * names of its contributors may be used to endorse or promote
 * products derived from this software without specific prior written
 * permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */

//----------------------------------------------------------------------------//

/*! \file InitIO.cpp
  Contains implementation of initIO function.
*/

//----------------------------------------------------------------------------//

#include "InitIO.h"

#include "DenseFieldIO.h"
#include "SparseFieldIO.h"
#include "MACFieldIO.h"
#include "FieldMappingIO.h"
#include "MIPFieldIO.h"

//----------------------------------------------------------------------------//

FIELD3D_NAMESPACE_OPEN

//----------------------------------------------------------------------------//

void initIO() 
{
  static boost::mutex mutex;
  boost::mutex::scoped_lock lock(mutex);

  ClassFactory &factory = ClassFactory::singleton();

  factory.registerFieldIO(DenseFieldIO::create);
  factory.registerFieldIO(SparseFieldIO::create);
  factory.registerFieldIO(MACFieldIO::create);
  factory.registerFieldIO(MIPFieldIO::create);

  factory.registerFieldMappingIO(NullFieldMappingIO::create);
  factory.registerFieldMappingIO(MatrixFieldMappingIO::create);
  factory.registerFieldMappingIO(FrustumFieldMappingIO::create);
}

//----------------------------------------------------------------------------//

FIELD3D_NAMESPACE_SOURCE_CLOSE

//----------------------------------------------------------------------------//

==> field3d_1.7.3.orig.tar.gz: Field3D-1.7.3/src/InitIO.cpp <==
//----------------------------------------------------------------------------//

/*
 * Copyright (c) 2009 Sony Pictures Imageworks Inc
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the
 * distribution.  Neither the name of Sony Pictures Imageworks nor the
 * names of its contributors may be used to endorse or promote
 * products derived from this software without specific prior written
 * permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */

//----------------------------------------------------------------------------//

/*! \file InitIO.cpp
  Contains implementation of initIO function.
*/

//----------------------------------------------------------------------------//

#include "InitIO.h"

#include "DenseFieldIO.h"
#include "SparseFieldIO.h"
#include "MACFieldIO.h"
#include "FieldMappingIO.h"
#include "MIPFieldIO.h"

//----------------------------------------------------------------------------//

FIELD3D_NAMESPACE_OPEN

//----------------------------------------------------------------------------//

namespace {

  size_t g_numIOThreads = 1;

}

//----------------------------------------------------------------------------//

void initIO() 
{
  static boost::mutex mutex;
  boost::mutex::scoped_lock lock(mutex);

  ClassFactory &factory = ClassFactory::singleton();

  factory.registerFieldIO(DenseFieldIO::create);
  factory.registerFieldIO(SparseFieldIO::create);
  factory.registerFieldIO(MACFieldIO::create);
  factory.registerFieldIO(MIPFieldIO::create);

  factory.registerFieldMappingIO(NullFieldMappingIO::create);
  factory.registerFieldMappingIO(MatrixFieldMappingIO::create);
  factory.registerFieldMappingIO(FrustumFieldMappingIO::create);
}

//----------------------------------------------------------------------------//

void setNumIOThreads(const size_t numThreads)
{
  g_numIOThreads = numThreads;
}

//----------------------------------------------------------------------------//

size_t numIOThreads()
{
  return g_numIOThreads;
}

//----------------------------------------------------------------------------//

FIELD3D_NAMESPACE_SOURCE_CLOSE

//----------------------------------------------------------------------------//
